##
##  python-text.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package versions
%define       V_python        3.12
%define       V_pygments      2.19.1
%define       V_configobj     5.0.9
%define       V_python_gflags 3.1.2
%define       V_jinja2        3.1.5
%define       V_mistune       3.1.0
%define       V_chardet       5.2.0

#   package information
Name:         python-text
Summary:      Python Modules for Text Manipulation
URL:          http://www.python.org/
Vendor:       Python Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Language
License:      GPL
Version:      %{V_python}
Release:      20250110

#   list of sources
Source0:      https://files.pythonhosted.org/packages/source/p/pygments/pygments-%{V_pygments}.tar.gz
Source1:      https://files.pythonhosted.org/packages/source/c/configobj/configobj-%{V_configobj}.tar.gz
Source2:      https://files.pythonhosted.org/packages/source/p/python-gflags/python-gflags-%{V_python_gflags}.tar.gz
Source3:      https://files.pythonhosted.org/packages/source/j/jinja2/jinja2-%{V_jinja2}.tar.gz
Source4:      https://files.pythonhosted.org/packages/source/m/mistune/mistune-%{V_mistune}.tar.gz
Source5:      https://files.pythonhosted.org/packages/source/c/chardet/chardet-%{V_chardet}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, python >= %{V_python}, python-setup
PreReq:       OpenPKG, openpkg >= 20160101, python >= %{V_python}

%description
    This is a set of Python extension modules for text manipulation.

%track
    prog python-text:pygments = {
        version   = %{V_pygments}
        url       = http://pypi.python.org/pypi/Pygments
        regex     = Pygments-(__VER__)\.tar\.gz
    }
    prog python-text:configobj = {
        version   = %{V_configobj}
        url       = http://pypi.python.org/pypi/configobj
        regex     = configobj-(__VER__)\.tar\.gz
    }
    prog python-text:python-gflags = {
        version   = %{V_python_gflags}
        url       = http://pypi.python.org/pypi/python-gflags
        regex     = python-gflags-(__VER__)\.tar\.gz
    }
    prog python-text:jinja2 = {
        version   = %{V_jinja2}
        url       = https://pypi.python.org/pypi/Jinja2
        regex     = Jinja2-(__VER__)\.tar\.gz
    }
    prog python-text:mistune = {
        version   = %{V_mistune}
        url       = https://pypi.python.org/pypi/mistune
        regex     = mistune-(__VER__)\.tar\.gz
    }
    prog python-text:chardet = {
        version   = %{V_chardet}
        url       = https://pypi.python.org/pypi/chardet
        regex     = chardet-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %setup -q -T -D -a 3
    %setup -q -T -D -a 4
    %setup -q -T -D -a 5

%build

%install
    export PYTHONPATH=$RPM_BUILD_ROOT%{l_prefix}/lib/python%{V_python}/site-packages
    ( cd pygments-%{V_pygments}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    ( cd configobj-%{V_configobj}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    ( cd python-gflags-%{V_python_gflags}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    ( cd jinja2-%{V_jinja2}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    ( cd mistune-%{V_mistune}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    ( cd chardet-%{V_chardet}
      HOME=`pwd` %{l_prefix}/bin/python \
          -m pip install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix} \
          --ignore-installed \
          --no-deps \
          .
    ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

